Examples
========

The following section gives an overview of the device/module specific
functionalities.

.. note::

   zhinst-toolkit offers high level support for all Zurich Instruments devices
   (Even though not all devices are listed below). Please refer to the overview
   of the :doc:`common functionalities <common_device>` for more information.

.. toctree::
   :caption: Devices
   :maxdepth: 2

   common_device
   hdawg
   hf2
   pqsc
   shfsg
   shfqa
   uhfqa
   uhf

.. toctree::
   :caption: Modules
   :maxdepth: 2

   awg
   daq_module
   scope_module
   sweeper_module
